% if report.purchases:

#### ${ _("Purchases") }

${ _("Code") } | ${ _("Status") } | ${ _("Responsible") } | ${ _("Branch") } | ${ _("Notes") } | ${ _("Supplier") } | ${ _("Purchase") } | ${ _("Method") } | ${ _("Details") } | ${ _("Value") }
% for purchase in report.purchases:
${ purchase.identifier } | ${ purchase.status_str } | ${ purchase.responsible_name } | ${ purchase.branch_name } | ${ purchase.notes } | ${ purchase.supplier_name } | - | - | - | ${ format_price(purchase.purchase_total) }
% for purchase_payment in report.purchases[purchase]:
|  |  |  |  |  | ${ purchase_payment.identifier } | ${ purchase_payment.method.get_description()} | % if purchase_payment.check_data: ${ _("Bank:") } ${ purchase_payment.check_data.bank_account.bank_number or ''} | ${ _("Agency:") } ${ purchase_payment.check_data.bank_account.bank_branch or ''} | ${ _("Acount:") } ${ purchase_payment.check_data.bank_account.bank_account or ''} % endif | ${ format_price(purchase_payment.value) }
% endfor % endfor

% endif